Index: src/gpu/batches/GrStencilAndCoverPathRenderer.cpp |
diff --git a/src/gpu/batches/GrStencilAndCoverPathRenderer.cpp b/src/gpu/batches/GrStencilAndCoverPathRenderer.cpp |
index 0995310c13e295810262c1753c55e15c7016fb37..4139629d14110cd0755ccc27e8be703dc9c04e41 100644 |
--- a/src/gpu/batches/GrStencilAndCoverPathRenderer.cpp |
+++ b/src/gpu/batches/GrStencilAndCoverPathRenderer.cpp |
@@ -33,8 +33,10 @@ GrStencilAndCoverPathRenderer::GrStencilAndCoverPathRenderer(GrResourceProvider* |
} |
bool GrStencilAndCoverPathRenderer::onCanDrawPath(const CanDrawPathArgs& args) const { |
- // GrPath doesn't support hairline paths. |
- if (args.fShape->style().couldBeHairline()) { |
+ // GrPath doesn't support hairline paths. An arbitrary path effect could produce a hairline |
+ // path. |
+ if (args.fShape->style().strokeRec().isHairlineStyle() || |
+ args.fShape->style().hasNonDashPathEffect()) { |
return false; |
} |
if (args.fHasUserStencilSettings) { |